package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Nov 6, 2024
License: Unlicense
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Pool[T any] interface {
Put(*T)
Get() *T
}
Pool is a typed wrapper for sync.Pool
func New[T any](new func() *T) Pool[T]
Create a new Pool
Source Files
¶
Click to show internal directories.
Click to hide internal directories.